@@ -1,4 +1,7 @@
-# $Id: __init__.py,v 1.2 2004/03/21 02:25:54 belyi Exp $
+# $Id$
+
+from pyme import util
+util.process_constants('GPGME_', globals())
 
 __all__ = ['data', 'event', 'import', 'keylist', 'md', 'pk',
            'protocol', 'sig', 'sigsum', 'status', 'validity']
